# Force python3 build - required by hplip
# % {?build_python3}%{?!build_python3:%bcond_without python3}
%bcond_without python3

%define enable_atlas 0
%{?_with_atlas: %global enable_atlas 1}

%define module	numpy

# disable this for bootstrapping nose and sphinx
%define enable_doc 0

Summary:	A fast multidimensional array facility for Python

Name:		python-%{module}
Epoch:		1
Version:	1.10.4
Release:	1
License:	BSD
Group:		Development/Python
Url: 		http://numpy.scipy.org
Source0:	http://downloads.sourceforge.net/numpy/numpy-%{version}.tar.gz
Patch0:		numpy-1.10.4-link.patch

%rename	f2py
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif
BuildRequires:	lapack-devel
BuildRequires:	gcc-gfortran >= 4.0
%if %enable_doc
BuildRequires:	python-sphinx >= 1.0
BuildRequires:	python-matplotlib
%endif
BuildRequires:	python-nose
BuildRequires:	python-devel
BuildRequires:	python-cython
BuildRequires:	python-setuptools
BuildRequires:	python-pkg-resources
%if %{with python3}
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-pkg-resources
BuildRequires:	python3-cython
BuildRequires:	python3-nose
BuildRequires:	python3-setuptools
%endif

%description
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package devel
Summary:	Numpy headers and development tools

Group:		Development/Python
Requires:	%{name} = %{EVRD}

%description devel
This package contains tools and header files need to develop modules 
in C and Fortran that can interact with Numpy

%if %{with python3}
%package -n python3-numpy
Summary:        A fast multidimensional array facility for Python3

Group:          Development/Python
License:        BSD

%description -n python3-numpy
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-numpy-devel
Summary:        Numpy headers and development tools

Group:          Development/Python
Requires:       python3-numpy = %{epoch}:%{version}-%{release}
# For include dir
Requires:	python-numpy-devel

%description -n python3-numpy-devel
This package contains tools and header files need to develop modules.
in C and Fortran that can interact with Numpy.
%endif

%prep
%setup -qn numpy-%{version}
%apply_patches

# workaround for rhbz#849713
# http://mail.scipy.org/pipermail/numpy-discussion/2012-July/063530.html
rm numpy/distutils/command/__init__.py && touch numpy/distutils/command/__init__.py

# Atlas 3.10 library names
cat >> site.cfg <<EOF
[atlas]
library_dirs = %{_libdir}/atlas
atlas_libs = satlas
EOF

%if %{with python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif

%build
%if %{with python3}
pushd %{py3dir}
env ATLAS=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags}" \
    python3 setup.py build
popd
%endif # with _python3

env ATLAS=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags}" \
    python setup.py build

%install
# first install python3 so the binaries are overwritten by the python2 ones
%if %{with python3}
pushd %{py3dir}
#%%{__python} setup.py install -O1 --skip-build --root %%{buildroot}
# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags}" \
    python3 setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
popd &> /dev/null

popd
%endif # with_python3

#%%{__python} setup.py install -O1 --skip-build --root %%{buildroot}
# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags}" \
    python setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
# symlink for anyone who was using f2py.numpy
ln -s f2py f2py.numpy
popd &> /dev/null
install -D -p -m 0644 doc/f2py/f2py.1 %{buildroot}%{_mandir}/man1/f2py.1

#symlink for includes, BZ 185079
mkdir -p %{buildroot}/usr/include
ln -s %{py_platsitedir}/%{name}/core/include/numpy/ %{buildroot}/usr/include/numpy

%check
pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{py_platsitedir}" python -c "import pkg_resources, numpy ; numpy.test()"
popd &> /dev/null

%if %{with python3}
pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{py3_platsitedir}" python3 -c "import pkg_resources, numpy ; numpy.test()"
popd &> /dev/null
%endif # with_python3

%files 
%doc LICENSE.txt README.txt THANKS.txt DEV_README.txt COMPATIBILITY site.cfg.example
%if %enable_doc
%doc doc/build/html
%endif
%dir %{py_platsitedir}/%{module}
%{py_platsitedir}/%{module}/*.py*
%{py_platsitedir}/%{module}/core/ 
%{py_platsitedir}/%{module}/compat/
%{py_platsitedir}/%{module}/doc/
%exclude %{py_platsitedir}/%{module}/core/include/
%exclude %{py_platsitedir}/%{module}/core/lib/*.a
%{py_platsitedir}/%{module}/fft/
%{py_platsitedir}/%{module}/lib/
%{py_platsitedir}/%{module}/linalg/
%{py_platsitedir}/%{module}/ma/
%{py_platsitedir}/%{module}/matrixlib/
%{py_platsitedir}/%{module}/polynomial/
%{py_platsitedir}/%{module}/random/
%exclude %{py_platsitedir}/%{module}/random/randomkit.h
%{py_platsitedir}/%{module}/testing/
%{py_platsitedir}/%{module}/tests/ 
%{py_platsitedir}/%{module}-*.egg-info

%files devel
%{_bindir}/f2py
%{_bindir}/f2py.numpy
%{_mandir}/man1/f2py.*
%{_includedir}/*
%{py_platsitedir}/%{module}/core/include/
%{py_platsitedir}/%{module}/core/lib/*.a
%{py_platsitedir}/%{module}/distutils/
%{py_platsitedir}/%{module}/f2py/
%{py_platsitedir}/%{module}/random/randomkit.h

%if %{with python3}
%files -n python3-numpy
%dir %{py3_platsitedir}/%{module}
%{py3_platsitedir}/%{module}/*.py*
%{py3_platsitedir}/%{module}/core
%{py3_platsitedir}/%{module}/doc/
%exclude %{py3_platsitedir}/%{module}/core/include/
%exclude %{py3_platsitedir}/%{module}/core/lib/*.a
%{py3_platsitedir}/%{module}/fft
%{py3_platsitedir}/%{module}/lib
%{py3_platsitedir}/%{module}/linalg
%{py3_platsitedir}/%{module}/ma
%{py3_platsitedir}/%{module}/random
%exclude %{py3_platsitedir}/%{module}/random/randomkit.h
%{py3_platsitedir}/%{module}/testing
%{py3_platsitedir}/%{module}/tests
%{py3_platsitedir}/%{module}/compat
%{py3_platsitedir}/%{module}/matrixlib
%{py3_platsitedir}/%{module}/polynomial
%{py3_platsitedir}/%{module}-*.egg-info

%files -n python3-numpy-devel
%{_bindir}/f2py3
%{py3_platsitedir}/%{module}/f2py
%{py3_platsitedir}/%{module}/core/include/
%{py3_platsitedir}/%{module}/core/lib/*.a
%{py3_platsitedir}/%{module}/distutils/
%{py3_platsitedir}/%{module}/random/randomkit.h
%endif

%changelog

* Mon Jan 25 2016 Denis Silakov <dsilakov@gmail.com> 1:1.10.4-1
- (5b97ab4) Updated to 1.10.4

* Wed Jun 17 2015 Denis Silakov <denis.silakov@rosalab.ru> 1:1.9.2-3
- (a2e7ebc) Force python3 build - required by hplip

* Tue Mar 03 2015 Denis Silakov <denis.silakov@rosalab.ru> 1:1.9.2-2
- (041fc0a) Fix python3 BRs
- (Denis Silakov: 915748d) Updated to 1.9.2, fix issues with importing numpy

* Sun Feb 22 2015 Alexander Lakhin <a.lahin@ntcit-rosa.ru> 1:1.9.1-2
- (ccf2df5) MassBuild#656: Increase release tag

* Tue Jan 27 2015 Denis Silakov <denis.silakov@rosalab.ru> 1:1.9.1-1
- (6c42297) Fix python3 conditional macros
- (Denis Silakov: bcbd3b0) Mke python3 build conditional
- (Denis Silakov: ae0478c) Updated to 1.9.1, fix build
- (Denis Silakov: 2e7d9c5) Updated to 1.9.1 (by updates_builder)

* Tue Oct 28 2014 Denis Silakov <denis.silakov@rosalab.ru> 1:1.9.0-1
- (f003aa4) Updated to 1.9.0 (by updates_builder)

* Tue Sep 09 2014 Denis Silakov <denis.silakov@rosalab.ru> 1:1.8.2-1
- (350ea72) Updated to 1.8.2 (by updates_builder)

* Fri Jun 27 2014 Alex Burmashev <alex.burmashev@rosalab.ru> 1:1.8.1-3
- (48a25f6) MassBuild#440: Increase release tag

* Mon Jun 23 2014 Denis Silakov <denis.silakov@rosalab.ru> 1:1.8.1-2
- (9ad5a29) Reuild with new python3
- (Denis Silakov: b14955b) Bump release

* Wed Apr 09 2014 Denis Silakov <denis.silakov@rosalab.ru> 1:1.8.1-1
- (08041c2) Updated to 1.8.1 (by updates_builder)

* Mon Mar 17 2014 Denis Silakov <denis.silakov@rosalab.ru> 1:1.8.0-1
- (cad9041) Updated to 1.8.0 (by updates_builder)

* Thu Dec 19 2013 Denis Silakov <denis.silakov@rosalab.ru> 1:1.7.1-6
- (6e573b4) Fix devel files location

* Thu Dec 19 2013 Denis Silakov <denis.silakov@rosalab.ru> 1:1.7.1-1
- (425e01f) Minor cleanup
- (Denis Silakov: 525a73b) Added python3 module
- (Denis Silakov: 5a7e1eb) Fix python BR
- (Denis Silakov: 3320da5) automatic rebuilder test -- 1.7.1

* Tue Nov 27 2012 Anton Kirilenko <anton.kirilenko@rosalab.ru> 1:1.7.0b2-1.auto
- (ce23754) automatic rebuilder test -- 1.7.0b2
- (Anton Kirilenko: 0b85aef) automatic rebuilder test -- 1.7.0b2

* Thu Nov 22 2012 Anton Kirilenko <anton.kirilenko@rosalab.ru> 1:1.6.2-4
- (9f6fb30) .abf.yml corrupted file has been repaired
- (Denis Silakov: d435add) Fix python macros
- (Denis Silakov: 61a1761) Drop shebang from non-executable scripts

* Mon Oct 15 2012 Dmitry Mikhirev <mikhirev@mezon.ru> 1:1.6.2-3
- (0dece84) remove tarball from git tree
- (Dmitry Mikhirev: 07220b7) some cleanups

* Mon Oct 15 2012 Dmitry Mikhirev <mikhirev@mezon.ru> 1:1.6.2-2
- (ed45f79) merge cooker specfile
- (Rosa: f94fa10) Automatic import for version 1.6.2-2

* Wed May 23 2012 Rosa <rosa@rosa-build.rosalab.ru> 1:1.6.2-1
- (aaf731f) Automatic import for version 1.6.2

* Tue Feb 21 2012 root <root@build-client_i586-1r.rosalab.ru> 1:1.6.1-2
- (9e59985) ABF:auto increment release
- (Rosa: 3b7b432) Automatic import for version 1.6.1


